@@ -1,3 +1,4 @@
 from .generatechangelog import GenerateChangelog
 from .githelper import GitHelper, FileCommit
-from .config import arg_parser
\ No newline at end of file
+
+__all__ = ['GenerateChangelog', 'GitHelper', 'FileCommit']
